@@ -4,9 +4,7 @@ import requests
 import json
 import requests.auth
 import aiohttp
-
 from random import SystemRandom
-import datetime
 
 from .reddit import Reddit
 from .exceptions import RequestError, EmptyResult
@@ -28,8 +26,8 @@ def get_request(client_auth, headers, rtype, slash, rfor):
     return json.loads(request.content)
 
 
-def check_for_api_error(response: dict):
-    if "message" in list(response.keys()):
+def check_for_api_error(response):
+    if "message" in list(response.keys() if type(response) != list else response[0].keys()):
         raise RequestError(f"{response['error']} {response['message']}")
 
 
@@ -47,10 +45,15 @@ def get_post(self, rtype, slash, rfor):
     check_for_api_error(meme)
 
     try:
-        post = meme["data"]["children"]
+        try:
+            post = meme["data"]["children"]
+            random_meme = meme["data"]["dist"]
+        except TypeError:
+            post = meme[0]["data"]["children"]
+            random_meme = meme[0]["data"]["dist"]
 
         try:
-            randompost = cryptogen.randint(0, meme["data"]["dist"] - 1)
+            randompost = cryptogen.randint(0, random_meme - 1)
             if post[randompost]["data"]["stickied"]:
                 randompost += 1
             nsfw = post[randompost]["data"]["over_18"]
@@ -66,7 +69,6 @@ def get_post(self, rtype, slash, rfor):
         spoiler = post[randompost]["data"]["spoiler"]
         s = post[randompost]["data"]["created"]
         media = post[randompost]["data"]["media"]
-        updated = datetime.datetime.fromtimestamp(s).strftime("%d-%m-%Y %I:%M:%S UTC")
 
         try:
             flair_author = post[randompost]["data"]["author_flair_text"]
@@ -78,7 +80,23 @@ def get_post(self, rtype, slash, rfor):
         except IndexError:
             flair_post = None
 
-        if not media:
+        try:
+            media_metadata = post[randompost]["data"]["media_metadata"]
+        except KeyError:
+            media_metadata = None
+
+        if media_metadata:
+            media_list = []
+
+            for i in range(len(media_metadata)):
+                media_list.append(media_metadata[list(media_metadata.keys())[i]]["s"]["u"])
+
+            contenttext = {
+                "mediaCount": len(media_metadata),
+                "media": media_list,
+                "fullData": media_metadata
+            }
+        elif not media:
             contenttext = post[randompost]["data"]["selftext"]
             if contenttext == "":
                 try:
@@ -99,12 +117,12 @@ def get_post(self, rtype, slash, rfor):
 
         regex_url_image = re.compile(
             r'(?:([^:/?#]+):)?(?://([^/?#]*))?([^?#]*\.(?:jpg|gif|png))(?:\?([^#]*))?(?:#(.*))?')
-        regex_url_video = re.compile(
-            r'(?:([^:/?#]+):)?(?://([^/?#]*))?([^?#]*\.(?:mov|mp4))(?:\?([^#]*))?(?:#(.*))?')
 
-        if re.match(regex_url_image, contenttext):
+        if type(contenttext) != str:
+            content_type = "Gallery"
+        elif re.match(regex_url_image, contenttext):
             content_type = "Image"
-        elif re.match(regex_url_video, contenttext):
+        elif post[randompost]["data"]["is_video"]:
             content_type = "Video"
         elif re.match(regex_url, contenttext):
             content_type = "URL"
@@ -119,7 +137,7 @@ def get_post(self, rtype, slash, rfor):
             score=post[randompost]["data"]["score"],
             downvotes=post[randompost]["data"]["downs"],
             nsfw=nsfw,
-            created_at=updated,
+            created_at=int(s),
             author=post[randompost]["data"]["author"],
             post_url=f"https://reddit.com{post[randompost]['data']['permalink']}"
                 .replace("https://reddit.com/r/u_", " https://reddit.com/u/"),
@@ -134,10 +152,15 @@ def get_post(self, rtype, slash, rfor):
             content_type=content_type
         )
     except KeyError:
-        post = meme["data"]["children"]
+        try:
+            post = meme["data"]["children"]
+            random_meme = meme["data"]["dist"]
+        except TypeError:
+            post = meme[0]["data"]["children"]
+            random_meme = meme[0]["data"]["dist"]
 
         try:
-            randompost = cryptogen.randint(0, meme["data"]["dist"] - 1)
+            randompost = cryptogen.randint(0, random_meme - 1)
             if post[randompost]["data"]["stickied"]:
                 randompost += 1
             nsfw = post[randompost]["data"]["over_18"]
@@ -162,9 +185,23 @@ def get_post(self, rtype, slash, rfor):
         except IndexError:
             flair_post = None
 
-        updated = datetime.datetime.fromtimestamp(s).strftime("%d-%m-%Y %I:%M:%S UTC")
+        try:
+            media_metadata = post[randompost]["data"]["media_metadata"]
+        except KeyError:
+            media_metadata = None
 
-        if not media:
+        if media_metadata:
+            media_list = []
+
+            for i in range(len(media_metadata)):
+                media_list.append(media_metadata[list(media_metadata.keys())[i]]["s"]["u"])
+
+            contenttext = {
+                "mediaCount": len(media_metadata),
+                "media": media_list,
+                "fullData": media_metadata
+            }
+        elif not media:
             contenttext = post[randompost]["data"]["url_overridden_by_dest"]
             if contenttext == "":
                 try:
@@ -175,23 +212,21 @@ def get_post(self, rtype, slash, rfor):
             try:
                 contenttext = post[randompost]["data"]["media"]["oembed"]["thumbnail_url"]
             except KeyError:
-                contenttext = post[randompost]["data"]["secure_media_embed"][
-                    "media_domain_url"]
+                contenttext = post[randompost]["data"]["secure_media_embed"]["media_domain_url"]
         else:
             contenttext = post[randompost]["data"]["url"]
 
         is_media = True if not post[randompost]["data"]["domain"].startswith("self") else False
 
         regex_url = re.compile(r'^(?:http|ftp)s?://')
-
         regex_url_image = re.compile(
             r'(?:([^:/?#]+):)?(?://([^/?#]*))?([^?#]*\.(?:jpg|gif|png))(?:\?([^#]*))?(?:#(.*))?')
-        regex_url_video = re.compile(
-            r'(?:([^:/?#]+):)?(?://([^/?#]*))?([^?#]*\.(?:mov|mp4))(?:\?([^#]*))?(?:#(.*))?')
 
-        if re.match(regex_url_image, contenttext):
+        if type(contenttext) != str:
+            content_type = "Gallery"
+        elif re.match(regex_url_image, contenttext):
             content_type = "Image"
-        elif re.match(regex_url_video, contenttext):
+        elif post[randompost]["data"]["is_video"]:
             content_type = "Video"
         elif re.match(regex_url, contenttext):
             content_type = "URL"
@@ -207,7 +242,7 @@ def get_post(self, rtype, slash, rfor):
             score=post[randompost]["data"]["score"],
             downvotes=post[randompost]["data"]["downs"],
             nsfw=nsfw,
-            created_at=updated,
+            created_at=int(s),
             author=post[randompost]["data"]["author"],
             post_url=f"https://reddit.com{post[randompost]['data']['permalink']}"
                 .replace("https://reddit.com/r/u_", " https://reddit.com/u/"),
@@ -236,10 +271,15 @@ async def get_async_post(self, rtype, rfor, slash):
     check_for_api_error(meme)
 
     try:
-        post = meme["data"]["children"]
+        try:
+            post = meme["data"]["children"]
+            random_meme = meme["data"]["dist"]
+        except TypeError:
+            post = meme[0]["data"]["children"]
+            random_meme = meme[0]["data"]["dist"]
 
         try:
-            randompost = cryptogen.randint(0, meme["data"]["dist"] - 1)
+            randompost = cryptogen.randint(0, random_meme - 1)
             if post[randompost]["data"]["stickied"]:
                 randompost += 1
             nsfw = post[randompost]["data"]["over_18"]
@@ -253,7 +293,6 @@ async def get_async_post(self, rtype, rfor, slash):
         spoiler = post[randompost]["data"]["spoiler"]
         s = post[randompost]["data"]["created"]
         media = post[randompost]["data"]["media"]
-        updated = datetime.datetime.fromtimestamp(s).strftime("%d-%m-%Y %I:%M:%S UTC")
 
         try:
             flair_author = post[randompost]["data"]["author_flair_text"]
@@ -265,7 +304,23 @@ async def get_async_post(self, rtype, rfor, slash):
         except IndexError:
             flair_post = None
 
-        if not media:
+        try:
+            media_metadata = post[randompost]["data"]["media_metadata"]
+        except KeyError:
+            media_metadata = None
+
+        if media_metadata:
+            media_list = []
+
+            for i in range(len(media_metadata)):
+                media_list.append(media_metadata[list(media_metadata.keys())[i]]["s"]["u"])
+
+            contenttext = {
+                "mediaCount": len(media_metadata),
+                "media": media_list,
+                "fullData": media_metadata
+            }
+        elif not media:
             contenttext = post[randompost]["data"]["selftext"]
             if contenttext == "":
                 try:
@@ -283,15 +338,14 @@ async def get_async_post(self, rtype, rfor, slash):
         is_media = True if not post[randompost]["data"]["domain"].startswith("self") else False
 
         regex_url = re.compile(r'^(?:http|ftp)s?://')
-
         regex_url_image = re.compile(
             r'(?:([^:/?#]+):)?(?://([^/?#]*))?([^?#]*\.(?:jpg|gif|png))(?:\?([^#]*))?(?:#(.*))?')
-        regex_url_video = re.compile(
-            r'(?:([^:/?#]+):)?(?://([^/?#]*))?([^?#]*\.(?:mov|mp4))(?:\?([^#]*))?(?:#(.*))?')
 
-        if re.match(regex_url_image, contenttext):
+        if type(contenttext) != str:
+            content_type = "Gallery"
+        elif re.match(regex_url_image, contenttext):
             content_type = "Image"
-        elif re.match(regex_url_video, contenttext):
+        elif post[randompost]["data"]["is_video"]:
             content_type = "Video"
         elif re.match(regex_url, contenttext):
             content_type = "URL"
@@ -307,7 +361,7 @@ async def get_async_post(self, rtype, rfor, slash):
             score=post[randompost]["data"]["score"],
             downvotes=post[randompost]["data"]["downs"],
             nsfw=nsfw,
-            created_at=updated,
+            created_at=int(s),
             author=post[randompost]["data"]["author"],
             post_url=f"https://reddit.com{post[randompost]['data']['permalink']}"
                 .replace("https://reddit.com/r/u_", " https://reddit.com/u/"),
@@ -322,10 +376,15 @@ async def get_async_post(self, rtype, rfor, slash):
             content_type=content_type
         )
     except KeyError:
-        post = meme["data"]["children"]
+        try:
+            post = meme["data"]["children"]
+            random_meme = meme["data"]["dist"]
+        except TypeError:
+            post = meme[0]["data"]["children"]
+            random_meme = meme[0]["data"]["dist"]
 
         try:
-            randompost = cryptogen.randint(0, meme["data"]["dist"] - 1)
+            randompost = cryptogen.randint(0, random_meme - 1)
             if post[randompost]["data"]["stickied"]:
                 randompost += 1
             nsfw = post[randompost]["data"]["over_18"]
@@ -350,9 +409,23 @@ async def get_async_post(self, rtype, rfor, slash):
         except IndexError:
             flair_post = None
 
-        updated = datetime.datetime.fromtimestamp(s).strftime("%d-%m-%Y %I:%M:%S UTC")
+        try:
+            media_metadata = post[randompost]["data"]["media_metadata"]
+        except KeyError:
+            media_metadata = None
 
-        if not media:
+        if media_metadata:
+            media_list = []
+
+            for i in range(len(media_metadata)):
+                media_list.append(media_metadata[list(media_metadata.keys())[i]]["s"]["u"])
+
+            contenttext = {
+                "mediaCount": len(media_metadata),
+                "media": media_list,
+                "fullData": media_metadata
+            }
+        elif not media:
             contenttext = post[randompost]["data"]["url_overridden_by_dest"]
             if contenttext == "":
                 try:
@@ -363,23 +436,21 @@ async def get_async_post(self, rtype, rfor, slash):
             try:
                 contenttext = post[randompost]["data"]["media"]["oembed"]["thumbnail_url"]
             except KeyError:
-                contenttext = post[randompost]["data"]["secure_media_embed"][
-                    "media_domain_url"]
+                contenttext = post[randompost]["data"]["secure_media_embed"]["media_domain_url"]
         else:
             contenttext = post[randompost]["data"]["url"]
 
         is_media = True if not post[randompost]["data"]["domain"].startswith("self") else False
 
         regex_url = re.compile(r'^(?:http|ftp)s?://')
-
         regex_url_image = re.compile(
             r'(?:([^:/?#]+):)?(?://([^/?#]*))?([^?#]*\.(?:jpg|gif|png))(?:\?([^#]*))?(?:#(.*))?')
-        regex_url_video = re.compile(
-            r'(?:([^:/?#]+):)?(?://([^/?#]*))?([^?#]*\.(?:mov|mp4))(?:\?([^#]*))?(?:#(.*))?')
 
-        if re.match(regex_url_image, contenttext):
+        if type(contenttext) != str:
+            content_type = "Gallery"
+        elif re.match(regex_url_image, contenttext):
             content_type = "Image"
-        elif re.match(regex_url_video, contenttext):
+        elif post[randompost]["data"]["is_video"]:
             content_type = "Video"
         elif re.match(regex_url, contenttext):
             content_type = "URL"
@@ -394,7 +465,7 @@ async def get_async_post(self, rtype, rfor, slash):
             score=post[randompost]["data"]["score"],
             downvotes=post[randompost]["data"]["downs"],
             nsfw=nsfw,
-            created_at=updated,
+            created_at=int(s),
             author=post[randompost]["data"]["author"],
             post_url=f"https://reddit.com{post[randompost]['data']['permalink']}"
                 .replace("https://reddit.com/r/u_", " https://reddit.com/u/"),
@@ -414,16 +485,14 @@ async def get_async_post(self, rtype, rfor, slash):
 
 
 class SubredditBase:
-    def __init__(self, subreddit, client_id=None, client_secret=None, user_agent=None):
-        self.subreddit = subreddit
+    def __init__(self, client_id=None, client_secret=None, user_agent=None):
         self.client_id = client_id
         self.client_secret = client_secret
         self.user_agent = user_agent
 
 
 class UserBase:
-    def __init__(self, user, client_id=None, client_secret=None, user_agent=None):
-        self.user = user
+    def __init__(self, client_id=None, client_secret=None, user_agent=None):
         self.user_agent = user_agent
         self.client_id = client_id
         self.client_secret = client_secret
